@@ -2,8 +2,11 @@
 Proxies are bridges between the world the agent acts in and the algorithm training loop.
 """
 
+
 from typing import Dict, Protocol
 
+from torch import nn
+
 from emote.typing import AgentId, DictObservation, DictResponse
 
 
@@ -17,6 +20,14 @@ class AgentProxy(Protocol):
         """Take observations for the active agents and returns the relevant network output."""
         ...
 
+    @property
+    def policy(self) -> nn.Module:
+        pass
+
+    @property
+    def input_names(self) -> tuple[str]:
+        ...
+
 
 class MemoryProxy(Protocol):
     """The interface between the agent in the game and the memory buffer the network trains from."""
